@@ -1,7 +1,7 @@
 """
 Type annotations for rbin service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rbin/paginators/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rbin/paginators/)
 
 Usage::
 
@@ -43,7 +43,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 class ListRulesPaginator(Boto3Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rbin.html#RecycleBin.Paginator.ListRules)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rbin/paginators/#listrulespaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rbin/paginators/#listrulespaginator)
     """
 
     def paginate(
@@ -55,5 +55,5 @@ class ListRulesPaginator(Boto3Paginator):
     ) -> _PageIterator[ListRulesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rbin.html#RecycleBin.Paginator.ListRules.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rbin/paginators/#listrulespaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rbin/paginators/#listrulespaginator)
         """
